@@ -51,6 +51,9 @@ class Almoststatic():
         self.cache = True
         """bool: global enable or disable cache"""
 
+        self.quote_escape = '``'
+        """str: sequence for quote escape in markdown translation"""
+
         # ------------------------------------------------------ runtime fields
         self.media_prefix = None
         """str | None: starting directory name to force url location for media
@@ -134,7 +137,7 @@ class Almoststatic():
         self.vars['len_list'] = len
         self.vars['iif'] = iif
         self.vars['if_in'] = if_in
-        self.vars['get_markdown'] = get_markdown
+        self.vars['get_markdown'] = self.get_markdown
         self.vars['get_media'] = self.get_media
         self.vars['include'] = self._import_file
         self.vars['embed'] = self.render_content
@@ -330,6 +333,26 @@ class Almoststatic():
         suffix = self.vars['url_suffix']
         return f"{self._relative_url()}{page}{suffix}{anchor}"
 
+    def get_markdown(self, text):
+        """convert markdown to html with tables extension.
+
+        double quote and single quotes by default can be escaped with "``"
+        sequence, this let to insert Jinja2 commands within links.
+        In markdown `[My Page]({{get_url("mylink")}})` produce an error because
+        markdown uses quotes to identify title attribute. So it can be
+        substituted with `[My Page]({{get_url(``mylink``)}})`. This mean that
+        you can use the sequence "``" only for links.
+
+        Args:
+            text (str): the text in markdown format
+        Returns:
+            str: the converted text
+        """
+        quote_marker = '\\:'
+        text = text.replace(self.quote_escape, quote_marker)
+        text = markdown.markdown(text, extensions=['tables'])
+        return text.replace(quote_marker, "'")
+
     def _relative_url(self):
         """"""
         if self.vars['url_prefix']:
@@ -382,6 +405,8 @@ class Almoststatic():
         for k, v in self.vars['meta_pages'].items():
             if 'blog' not in v:
                 continue
+            if v['blog'].get('disabled', False):
+                continue
 
             def _check(lquery, ldata):
                 """check if page belongs to categories or tags in query. return
@@ -567,7 +592,7 @@ class Almoststatic():
                     text += self.render_content(value['content'])
                 value = text
             else:
-                value = get_markdown(value)
+                value = self.get_markdown(value)
         return value
 
     def _import_file(self, filename):
@@ -587,7 +612,7 @@ class Almoststatic():
                 s = f.read()
             elif fname.endswith('.md'):
                 s = f.read()
-                s = get_markdown(s)
+                s = self.get_markdown(s)
             elif fname.endswith('.yaml'):
                 content = yaml.load(f, Loader=yaml.FullLoader)
                 s = self.render_content(content)
@@ -651,17 +676,6 @@ class FlaskAlmoststatic(Almoststatic):
         return s
 
 
-def get_markdown(text):
-    """convert markdown to html and render tables
-
-    Args:
-        text (str): the text in markdown format
-    Returns:
-        str: the converted text
-    """
-    return markdown.markdown(text, extensions=['tables'])
-
-
 def iif(condition, if_true, if_false=""):
     """Inline if short code
     try: iif(1==1, "Ok", "No")
